==> lori_sdk-0.0.1.tar.gz: lib/data/models/cart/paymentMethod.dart <==
import 'package:flutter/widgets.dart';
import 'package:json_annotation/json_annotation.dart';
part 'paymentMethod.g.dart';

@JsonSerializable()
class PaymentMethod {
//  static const BRANDS = ['AmEx', 'DinersClub', 'Discover', 'JCB', 'MasterCard', 'Visa', 'Maestro', 'Master'];
  static const BRANDS = ['AmEx', 'Diners', 'Elo', 'Hipercard', 'MasterCard', 'Visa'];

  static const TYPE_CREDIT = 1;
  static const TYPE_ON_STORE = 2;
  static const TYPE_BANKSLIP = 3;

  PaymentMethod();

  String clientId;
  String id;
  String name;
  String info;
  int type;
  double discount;

  String cardHolder;
  String brand;
  String finalNumber;

  String displayName() {
    switch (type) {
      case 1:
        return brand.toUpperCase() + ' - final ' + finalNumber;
      case 2:
        return info;
      case 3:
        return info;
      default:
        return info;
    }
  }

  static AssetImage brandImage(String brand) {
    if (brand != null) {
      switch (brand.toLowerCase()) {
        case 'amex':
          return AssetImage('assets/ic_amex.png');
        case 'master':
        case 'mastercard':
        case 'maestro':
          return AssetImage('assets/ic_mastercard.png');
        case 'diners':
        case 'discover':
          return AssetImage('assets/ic_discover.png');
        case 'jcb':
          return AssetImage('assets/ic_jcb.png');
        case 'elo':
          return AssetImage('assets/ic_elo.png');
        case 'hipercard':
          return AssetImage('assets/ic_hipercard.png');
        default:
          return AssetImage('assets/ic_visa.png');
      }
    } else {
      return AssetImage('assets/ic_visa.png');
    }
  }

  factory PaymentMethod.fromJson(Map<String, dynamic> json) => _$PaymentMethodFromJson(json);
  Map<String, dynamic> toJson() => _$PaymentMethodToJson(this);
}

@JsonSerializable()
class CreditCardBrand {
  CreditCardBrand();

  String brandName;

  factory CreditCardBrand.fromJson(Map<String, dynamic> json) => _$CreditCardBrandFromJson(json);
  Map<String, dynamic> toJson() => _$CreditCardBrandToJson(this);
}

enum PaymentMethodType {
  //Workaround because dart does not support enums starting at 0
  @JsonValue(0)
  none,

  @JsonValue(1)
  credit,

  @JsonValue(2)
  on_store,

  @JsonValue(3)
  bankslip
}

==> lori_sdk-0.1.10.tar.gz: lib/data/models/cart/paymentMethod.dart <==
import 'package:flutter/widgets.dart';
import 'package:json_annotation/json_annotation.dart';

part 'paymentMethod.g.dart';

@JsonSerializable()
class PaymentMethod {
//  static const BRANDS = ['AmEx', 'DinersClub', 'Discover', 'JCB', 'MasterCard', 'Visa', 'Maestro', 'Master'];
  static const BRANDS = [
    'AmEx',
    'Diners',
    'Elo',
    'Hipercard',
    'MasterCard',
    'Visa'
  ];

  static const TYPE_CREDIT = 1;
  static const TYPE_ON_STORE = 2;
  static const TYPE_BANKSLIP = 3;

  PaymentMethod();

  String clientId;
  String id;
  String name;
  String info;
  int type;
  double discount;

  String cardHolder;
  String brand;
  String finalNumber;

  String displayName() {
    switch (type) {
      case 1:
        return brand.toUpperCase() + ' - final ' + finalNumber;
      case 2:
        return info;
      case 3:
        return info;
      default:
        return info;
    }
  }

  static AssetImage brandImage(String brand) {
    if (brand != null) {
      switch (brand.toLowerCase()) {
        case 'amex':
          return AssetImage('assets/ic_amex.png');
        case 'master':
        case 'mastercard':
        case 'maestro':
          return AssetImage('assets/ic_mastercard.png');
        case 'diners':
        case 'discover':
          return AssetImage('assets/ic_discover.png');
        case 'jcb':
          return AssetImage('assets/ic_jcb.png');
        case 'elo':
          return AssetImage('assets/ic_elo.png');
        case 'hipercard':
          return AssetImage('assets/ic_hipercard.png');
        default:
          return AssetImage('assets/ic_visa.png');
      }
    } else {
      return AssetImage('assets/ic_visa.png');
    }
  }

  factory PaymentMethod.fromJson(Map<String, dynamic> json) =>
      _$PaymentMethodFromJson(json);

  Map<String, dynamic> toJson() => _$PaymentMethodToJson(this);
}

@JsonSerializable()
class CreditCardBrand {
  CreditCardBrand();

  String brandName;

  factory CreditCardBrand.fromJson(Map<String, dynamic> json) =>
      _$CreditCardBrandFromJson(json);

  Map<String, dynamic> toJson() => _$CreditCardBrandToJson(this);
}

enum PaymentMethodType {
//Workaround because dart does not support enums starting at 0
  @JsonValue(0)
  none,

  @JsonValue(1)
  credit,

  @JsonValue(2)
  on_store,

  @JsonValue(3)
  bankslip
}
